==> ejc-supbid-impl-3.0.1-20211123.065831-3-sources.jar: com/ejianc/business/supbid/notice/bean/SignEntity.java <==
package com.ejianc.business.supbid.notice.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 报名实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_supbid_sign")
public class SignEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="notice_id")
    private java.lang.Long noticeId; // 主表主键
    @TableField(value="source_id")
    private java.lang.String sourceId; // 招标信息主键
    @TableField(value="source_tenant_id")
    private java.lang.String sourceTenantId;
    @TableField(value="source_supplier_id")
    private java.lang.String sourceSupplierId;//供应商来源主键
    @TableField(value="sign_status")
    private java.lang.Integer signStatus; // 状态(0-已报名，1-待报价，2-洽商谈判，3-报价中，4-已定标，5-已淘汰)
    @TableField(value="out_reason")
    private java.lang.String outReason; // 淘汰原因
    @TableField(value="employee_id")
    private java.lang.Long employeeId; // 报名联系人
    @TableField(value="employee_name")
    private java.lang.String employeeName; // 报名联系人名称
    @TableField(value="employee_mobile")
    private java.lang.String employeeMobile; // 报名联系人电话
    @TableField(value="invoice_note")
    private java.lang.String invoiceNote; // 发票说明
    @TableField(value="sign_time")
    private java.util.Date signTime; // 报名时间
    @TableField(value="scheme_time")
    private java.util.Date schemeTime; // 报价时间
    @TableField(value="sign_id")
    private java.lang.Long signId; // 报名操作人
    @TableField(value="sign_name")
    private java.lang.Long signName; // 报名操作人名称
    @TableField(value="scheme_id")
    private java.lang.String schemeId; // 报价操作人
    @TableField(value="scheme_name")
    private java.lang.String schemeName; // 报价操作人名称

    public String getSourceTenantId() {
        return sourceTenantId;
    }

    public void setSourceTenantId(String sourceTenantId) {
        this.sourceTenantId = sourceTenantId;
    }

    public String getSourceSupplierId() {
        return sourceSupplierId;
    }

    public void setSourceSupplierId(String sourceSupplierId) {
        this.sourceSupplierId = sourceSupplierId;
    }

    /**
     * 主表主键
     */
    public java.lang.Long getNoticeId() {
        return noticeId;
    }

    /**
     * 主表主键
     */
    public void setNoticeId(java.lang.Long noticeId) {
        this.noticeId = noticeId;
    }
    /**
     * 招标信息主键
     */
    public java.lang.String getSourceId() {
        return sourceId;
    }

    /**
     * 招标信息主键
     */
    public void setSourceId(java.lang.String sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 状态(0-已报名，1-待报价，2-洽商谈判，3-报价中，4-已定标，5-已淘汰)
     */
    public java.lang.Integer getSignStatus() {
        return signStatus;
    }

    /**
     * 状态(0-已报名，1-待报价，2-洽商谈判，3-报价中，4-已定标，5-已淘汰)
     */
    public void setSignStatus(java.lang.Integer signStatus) {
        this.signStatus = signStatus;
    }
    /**
     * 淘汰原因
     */
    public java.lang.String getOutReason() {
        return outReason;
    }

    /**
     * 淘汰原因
     */
    public void setOutReason(java.lang.String outReason) {
        this.outReason = outReason;
    }
    /**
     * 报名联系人
     */
    public java.lang.Long getEmployeeId() {
        return employeeId;
    }

    /**
     * 报名联系人
     */
    public void setEmployeeId(java.lang.Long employeeId) {
        this.employeeId = employeeId;
    }
    /**
     * 报名联系人名称
     */
    public java.lang.String getEmployeeName() {
        return employeeName;
    }

    /**
     * 报名联系人名称
     */
    public void setEmployeeName(java.lang.String employeeName) {
        this.employeeName = employeeName;
    }
    /**
     * 报名联系人电话
     */
    public java.lang.String getEmployeeMobile() {
        return employeeMobile;
    }

    /**
     * 报名联系人电话
     */
    public void setEmployeeMobile(java.lang.String employeeMobile) {
        this.employeeMobile = employeeMobile;
    }
    /**
     * 发票说明
     */
    public java.lang.String getInvoiceNote() {
        return invoiceNote;
    }

    /**
     * 发票说明
     */
    public void setInvoiceNote(java.lang.String invoiceNote) {
        this.invoiceNote = invoiceNote;
    }
    /**
     * 报名时间
     */
    public java.util.Date getSignTime() {
        return signTime;
    }

    /**
     * 报名时间
     */
    public void setSignTime(java.util.Date signTime) {
        this.signTime = signTime;
    }
    /**
     * 报价时间
     */
    public java.util.Date getSchemeTime() {
        return schemeTime;
    }

    /**
     * 报价时间
     */
    public void setSchemeTime(java.util.Date schemeTime) {
        this.schemeTime = schemeTime;
    }
    /**
     * 报名操作人
     */
    public java.lang.Long getSignId() {
        return signId;
    }

    /**
     * 报名操作人
     */
    public void setSignId(java.lang.Long signId) {
        this.signId = signId;
    }
    /**
     * 报名操作人名称
     */
    public java.lang.Long getSignName() {
        return signName;
    }

    /**
     * 报名操作人名称
     */
    public void setSignName(java.lang.Long signName) {
        this.signName = signName;
    }
    /**
     * 报价操作人
     */
    public java.lang.String getSchemeId() {
        return schemeId;
    }

    /**
     * 报价操作人
     */
    public void setSchemeId(java.lang.String schemeId) {
        this.schemeId = schemeId;
    }
    /**
     * 报价操作人名称
     */
    public java.lang.String getSchemeName() {
        return schemeName;
    }

    /**
     * 报价操作人名称
     */
    public void setSchemeName(java.lang.String schemeName) {
        this.schemeName = schemeName;
    }
    
}

==> ejc-supbid-impl-3.0.1-20211123.093525-5-sources.jar: com/ejianc/business/supbid/notice/bean/SignEntity.java <==
package com.ejianc.business.supbid.notice.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 报名实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_supbid_sign")
public class SignEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="notice_id")
    private java.lang.Long noticeId; // 主表主键
    @TableField(value="source_id")
    private java.lang.String sourceId; // 招标信息主键
    @TableField(value="source_tenant_id")
    private java.lang.String sourceTenantId;
    @TableField(value="source_supplier_id")
    private java.lang.String sourceSupplierId;//供应商来源主键
    @TableField(value="sign_status")
    private java.lang.Integer signStatus; // 状态(0-已报名，1-待报价，2-洽商谈判，3-报价中，4-已定标，5-已淘汰)
    @TableField(value="out_reason")
    private java.lang.String outReason; // 淘汰原因
    @TableField(value="employee_id")
    private java.lang.Long employeeId; // 报名联系人
    @TableField(value="employee_name")
    private java.lang.String employeeName; // 报名联系人名称
    @TableField(value="employee_mobile")
    private java.lang.String employeeMobile; // 报名联系人电话
    @TableField(value="invoice_note")
    private java.lang.String invoiceNote; // 发票说明
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    @TableField(value="sign_time")
    private java.util.Date signTime; // 报名时间
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    @TableField(value="scheme_time")
    private java.util.Date schemeTime; // 报价时间
    @TableField(value="sign_id")
    private java.lang.Long signId; // 报名操作人
    @TableField(value="sign_name")
    private java.lang.Long signName; // 报名操作人名称
    @TableField(value="scheme_id")
    private java.lang.String schemeId; // 报价操作人
    @TableField(value="scheme_name")
    private java.lang.String schemeName; // 报价操作人名称

    public String getSourceTenantId() {
        return sourceTenantId;
    }

    public void setSourceTenantId(String sourceTenantId) {
        this.sourceTenantId = sourceTenantId;
    }

    public String getSourceSupplierId() {
        return sourceSupplierId;
    }

    public void setSourceSupplierId(String sourceSupplierId) {
        this.sourceSupplierId = sourceSupplierId;
    }

    /**
     * 主表主键
     */
    public java.lang.Long getNoticeId() {
        return noticeId;
    }

    /**
     * 主表主键
     */
    public void setNoticeId(java.lang.Long noticeId) {
        this.noticeId = noticeId;
    }
    /**
     * 招标信息主键
     */
    public java.lang.String getSourceId() {
        return sourceId;
    }

    /**
     * 招标信息主键
     */
    public void setSourceId(java.lang.String sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 状态(0-已报名，1-待报价，2-洽商谈判，3-报价中，4-已定标，5-已淘汰)
     */
    public java.lang.Integer getSignStatus() {
        return signStatus;
    }

    /**
     * 状态(0-已报名，1-待报价，2-洽商谈判，3-报价中，4-已定标，5-已淘汰)
     */
    public void setSignStatus(java.lang.Integer signStatus) {
        this.signStatus = signStatus;
    }
    /**
     * 淘汰原因
     */
    public java.lang.String getOutReason() {
        return outReason;
    }

    /**
     * 淘汰原因
     */
    public void setOutReason(java.lang.String outReason) {
        this.outReason = outReason;
    }
    /**
     * 报名联系人
     */
    public java.lang.Long getEmployeeId() {
        return employeeId;
    }

    /**
     * 报名联系人
     */
    public void setEmployeeId(java.lang.Long employeeId) {
        this.employeeId = employeeId;
    }
    /**
     * 报名联系人名称
     */
    public java.lang.String getEmployeeName() {
        return employeeName;
    }

    /**
     * 报名联系人名称
     */
    public void setEmployeeName(java.lang.String employeeName) {
        this.employeeName = employeeName;
    }
    /**
     * 报名联系人电话
     */
    public java.lang.String getEmployeeMobile() {
        return employeeMobile;
    }

    /**
     * 报名联系人电话
     */
    public void setEmployeeMobile(java.lang.String employeeMobile) {
        this.employeeMobile = employeeMobile;
    }
    /**
     * 发票说明
     */
    public java.lang.String getInvoiceNote() {
        return invoiceNote;
    }

    /**
     * 发票说明
     */
    public void setInvoiceNote(java.lang.String invoiceNote) {
        this.invoiceNote = invoiceNote;
    }
    /**
     * 报名时间
     */
    public java.util.Date getSignTime() {
        return signTime;
    }

    /**
     * 报名时间
     */
    public void setSignTime(java.util.Date signTime) {
        this.signTime = signTime;
    }
    /**
     * 报价时间
     */
    public java.util.Date getSchemeTime() {
        return schemeTime;
    }

    /**
     * 报价时间
     */
    public void setSchemeTime(java.util.Date schemeTime) {
        this.schemeTime = schemeTime;
    }
    /**
     * 报名操作人
     */
    public java.lang.Long getSignId() {
        return signId;
    }

    /**
     * 报名操作人
     */
    public void setSignId(java.lang.Long signId) {
        this.signId = signId;
    }
    /**
     * 报名操作人名称
     */
    public java.lang.Long getSignName() {
        return signName;
    }

    /**
     * 报名操作人名称
     */
    public void setSignName(java.lang.Long signName) {
        this.signName = signName;
    }
    /**
     * 报价操作人
     */
    public java.lang.String getSchemeId() {
        return schemeId;
    }

    /**
     * 报价操作人
     */
    public void setSchemeId(java.lang.String schemeId) {
        this.schemeId = schemeId;
    }
    /**
     * 报价操作人名称
     */
    public java.lang.String getSchemeName() {
        return schemeName;
    }

    /**
     * 报价操作人名称
     */
    public void setSchemeName(java.lang.String schemeName) {
        this.schemeName = schemeName;
    }
    
}
